import os,os.path,string,commands
import cherrypy
from Common import config,DetConfig
from cherrypy.lib import static
import pickle

class IOV(object):
    def __init__(self,configfilepath):
        self.__config=config.Config()
        self.__config.from_ini(configfilepath)
        self.__authpath=self.__config.common.auth_path
        self.__datasavedir=self.__config.common.datasave_dir
        self.__detconfig=DetConfig.DetConfig(self.__config.iovold.detector_conf)
        self.__condcorebase=self.__config.iovold.condcore
        self.__mypath=self.__condcorebase+'/bin:'        
        self.__myldpath=self.__condcorebase+'/lib'+':'+self.__condcorebase+'/external:'

    @cherrypy.expose
    def index(self):
        """Top level page
        """
        overviewstr=['IOV inspection service']
        overviewstr.append(str(self.__authpath))
        overviewstr.append(str(self.__datasavedir))
        return (' ').join(overviewstr)   
    
    def __getconnectstr(self,det,service,schema,viacache):
        """Assemble full connect string with given parameters
        """
        connect_str=''
        if len(viacache)==0:
            if (service.find(":"))==-1 :
               connect_str+='oracle://'
            connect_str+=service+'/'+schema          
        else:            
            #knownservices=self.__detconfig.services(det)
            #if '/'.join([service,schema]) not in knownservices:
            #   return ''
            servletname=self.__detconfig.serviceToServlet(det,service)
            connect_str+='\"frontier://(serverurl=http://cmsfrontier.cern.ch:8000/'+servletname+')/'+schema+'\"'
            #print 'connect_str',connect_str
        if len(connect_str)==0:
            return "Application Server Error: requested service "+service+" "+schema+"is not configured"
        return connect_str
    
    @cherrypy.expose
    def getTags(self,det,service,schema,viacache):
        """Get list of tags
        """
        connect_str=self.__getconnectstr(det,service,schema,viacache)
        if len(connect_str)==0:
            return "Application Server Error: requested service "+service+" "+schema+"is not configured"
        cmd=['cmscond_list_iov','-a','-c',connect_str]
        if connect_str.find('oracle://') != -1:
            cmd.append('-P')
            cmd.append(self.__authpath)
        cmdstr=' '.join(cmd)
        #print cmdstr
        os.environ['PATH']=self.__mypath+os.environ['PATH']
        os.environ['LD_LIBRARY_PATH']=self.__myldpath+os.environ['LD_LIBRARY_PATH']
        cmdout = commands.getoutput(cmdstr)
        #env reset
        os.environ['PATH'].replace(self.__mypath,'',1)
        os.environ['LD_LIBRARY_PATH'].replace(self.__myldpath,'',1)
        #print cmdout
        results = string.split(cmdout,'\n')
        result=''
        for entry in results:
            result += entry.strip() +';'
        return result
                
    @cherrypy.expose
    def getIOVForTag(self,det,service,schema,tag,since, till, head, tail, viacache):
        """Get iov info for given tag in the given range
        """
        #if (0==len(till)) : till = 0
        #if (0==len(since)) : since = 0
        #if (0==len(head)) : head = 0
        #if (0==len(tail)) : tail = 0

        connect_str=self.__getconnectstr(det,service,schema,viacache)
        if len(connect_str)==0:
            return "Application Server Error: requested service "+service+" "+schema+"is not configured"
        cmd=['cmscond_list_iov','-t',tag,'-c',connect_str]
        if connect_str.find('oracle://') != -1:
            cmd.append('-P')
            cmd.append(self.__authpath)
        cmdstr=' '.join(cmd)
        #print cmdstr
        os.environ['PATH']=self.__mypath+os.environ['PATH']
        os.environ['LD_LIBRARY_PATH']=self.__myldpath+os.environ['LD_LIBRARY_PATH']
        cmdout = commands.getoutput(cmdstr)
        os.environ['PATH'].replace(self.__mypath,'',1)
        os.environ['LD_LIBRARY_PATH'].replace(self.__myldpath,'',1)
        #print cmdout
        results = string.split(cmdout,'\n')
        #print 'app server result ',results
        result=''
        for entry in results:
            result += entry.strip() +';'
        return result

