import os,sys
import cherrypy
import simplejson as json
from Common import config,DetConfig
from CondCore.Utilities import iovInspector as inspect
import pluginCondDBPyInterface as CondDB
from CondCore.Utilities import timeUnitHelper
import pickle

class lumi(object):
   def __init__(self,configfilepath):
      self.__config=config.Config()
      self.__config.from_ini(configfilepath)
      self.__authpath=self.__config.common.auth_path
      self.__rdbms=CondDB.RDBMS(self.__authpath)
      self.__accountlist=['oracle://cms_orcoff_prod/CMS_COND_31X_RUN_INFO']
      #self.__accountlist=['oracle://cms_orcoff_prod/CMS_COND_31X_RUN_INFO','oracle://cms_orcoff_prep/CMS_COND_RUN_INFO']
   @cherrypy.expose
   def index(self):
      return 'lumiappserver' 

   @cherrypy.expose
   def allLumiTags(self):
      """all lumi related tags and their summary info sorted by account name
      """
      #dataschema={'fields':['tagname','classname','timetype','startrun','endrun','operationlog','revision','plot']}
      #result={'dataschema':dataschema, 'datainaccounts':[]}
      result={}
      #print dataschema
      for account in self.__accountlist:
#        print 'processing account',account
        try:
           db = self.__rdbms.getDB(account)
           tags = db.allTags()
           result[account]={'status':'UNKNOWN','data':[]}
           #print tags
           for tag in tags.split(' '):
              r={}
              r['tagname']=tag
              iov=inspect.Iov(db,tag)
              r['operationlog']=iov.comment()
              r['revision']=iov.revision()
              r['classname']=iov.payloadContainerName()
              if r['classname']=='LuminosityInfo':
                 r['plot']=1
              else:
                 r['plot']=0
              if str(iov.timetype()) != 'lumiid' : break
              r['accountname']=account
              suma=iov.list()
              #print suma[0][1]
              r['startrun']=timeUnitHelper.unpackLumiid(suma[0][1])['run']
              #print 'startrun',r['startrun']
              r['endrun']=timeUnitHelper.unpackLumiid(suma[-1][1])['run']
              #print 'endrun',r['endrun']
              result[account]['data'].append(r)
              #print r
        except Exception, er:           
           result[account]['status']=str(er)
        except RuntimeError:           
           result[account]['status']= 'RuntimeError'
        except:
           result[account]['status']= 'unknownerror'
      return json.dumps(result)
   
   @cherrypy.expose
   def LumiSummaries(self,account,tag):
      """retrieve lumi section summary data per tag in given account
      """
      trend=[]
      try:
           db = self.__rdbms.getDB(account)
           iov = inspect.Iov(db,tag)
           trend=iov.trend({})
           firstentry=trend[0][0]
           lastentry=trend[-1][0]
           firstrun=timeUnitHelper.unpackLumiid(firstentry)['run']
           lastrun=timeUnitHelper.unpackLumiid(lastentry)['run']
           result={}
           for run in range(firstrun,lastrun+1):
              lumisecdata={}
              for entry in trend:
                 r=timeUnitHelper.unpackLumiid(entry[0])['run']
                 if r==run:
                    lumiavg=entry[2][0]
                    sect=timeUnitHelper.unpackLumiid(entry[0])['lumisection']
                    lumisecdata[sect]=(lumiavg,0.9)
              result[run]=lumisecdata
      except Exception, er:           
           print str(er)
      except RuntimeError:           
           print 'RuntimeError'
      except:
           print 'unknownerror'
      #keeps bulk data with number index pickled
      return pickle.dumps(result)
